@@ -6,6 +6,8 @@ use Benchmark qw(cmpthese timethese);
 use File::Basename;
 
 use PerlIO::Util;
+print "PerlIO::Util/$PerlIO::Util::VERSION\n\n";
+
 my $perlbin = -d '/usr/bin' ? '/usr/bin' : dirname $^X;
 
 my $count = do{
@@ -14,7 +16,7 @@ my $count = do{
 	$n++ while defined(my $d = <$dir>);
 	$n;
 };
-print "read: $count\n";
+print "Number of files: $count\n";
 
 cmpthese timethese -1 => {
 	layer => sub{
